==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractBusinessUnitsTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractBusinessUnitsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _38_1_12021265285 _38_1_12021265285;
	public Loading loading;
	public BusinessUnitsTemplate.Loading. _39_31_01131215905 _39_31_01131215905;
	public UnitsBlock unitsBlock;
	public BusinessUnitsTemplate.UnitsBlock. Units units;

    public AbstractBusinessUnitsTemplate(B box) {
        super(box);
        id("businessUnitsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_38_1_12021265285 == null) _38_1_12021265285 = register(new _38_1_12021265285(box()).<_38_1_12021265285>id("a164036846").owner(AbstractBusinessUnitsTemplate.this));
		if (loading == null) loading = register(new Loading(box()).<Loading>id("a1942466599").owner(AbstractBusinessUnitsTemplate.this));
		if (loading != null) _39_31_01131215905 = loading._39_31_01131215905;
		if (unitsBlock == null) unitsBlock = register(new UnitsBlock(box()).<UnitsBlock>id("a290590611").owner(AbstractBusinessUnitsTemplate.this));
		if (unitsBlock != null) units = unitsBlock.units;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_38_1_12021265285 != null) _38_1_12021265285.unregister();
	    if (loading != null) loading.unregister();
	    if (unitsBlock != null) unitsBlock.unregister();
	}

	public class _38_1_12021265285 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public _38_1_12021265285(B box) {
			super(box);
			_value("Business units");
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class Loading extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public BusinessUnitsTemplate.Loading. _39_31_01131215905 _39_31_01131215905;

		public Loading(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_39_31_01131215905 == null) _39_31_01131215905 = register(new _39_31_01131215905(box()).<_39_31_01131215905>id("a2134995911").owner(AbstractBusinessUnitsTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_39_31_01131215905 != null) _39_31_01131215905.unregister();
		}

		public class _39_31_01131215905 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

			public _39_31_01131215905(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class UnitsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public BusinessUnitsTemplate.UnitsBlock. Units units;

		public UnitsBlock(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (units == null) units = register(new Units((UnitBox)box()).<Units>id("a_767586365").owner(AbstractBusinessUnitsTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (units != null) units.unregister();
		}

		public class Units extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,BusinessUnitTemplate, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,BusinessUnitTemplate, java.lang.Void> {

			public Units(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}

			@Override
			public BusinessUnitTemplate add(java.lang.Void value) {
				BusinessUnitTemplate child = new BusinessUnitTemplate(box());
				child.id(java.util.UUID.randomUUID().toString());
				add(child, "units");
			    notifyAdd(child);
				return child;
			}
			@Override
			public void remove(BusinessUnitTemplate child) {
				removeChild(child, "units");
			}
			public void clear() {
			    super.clear("units");
			}
		}
	}
}

==> unit-1.3.8-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractBusinessUnitsTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractBusinessUnitsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _38_1_12021265285 _38_1_12021265285;
	public Loading loading;
	public BusinessUnitsTemplate.Loading. _39_31_01131215905 _39_31_01131215905;
	public UnitsBlock unitsBlock;
	public BusinessUnitsTemplate.UnitsBlock. Units units;

	public AbstractBusinessUnitsTemplate(B box) {
		super(box);
		id("businessUnitsTemplate");
	}

	@Override
	public void init() {
		super.init();
		if (_38_1_12021265285 == null) _38_1_12021265285 = register(new _38_1_12021265285(box()).<_38_1_12021265285>id("a164036846").owner(AbstractBusinessUnitsTemplate.this));
		if (loading == null) loading = register(new Loading(box()).<Loading>id("a1942466599").owner(AbstractBusinessUnitsTemplate.this));
		if (loading != null) _39_31_01131215905 = loading._39_31_01131215905;
		if (unitsBlock == null) unitsBlock = register(new UnitsBlock(box()).<UnitsBlock>id("a290590611").owner(AbstractBusinessUnitsTemplate.this));
		if (unitsBlock != null) units = unitsBlock.units;
	}

	@Override
	public void remove() {
		super.remove();
		if (_38_1_12021265285 != null) _38_1_12021265285.unregister();
		if (loading != null) loading.unregister();
		if (unitsBlock != null) unitsBlock.unregister();
	}

	public class _38_1_12021265285 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public _38_1_12021265285(B box) {
			super(box);
			_value("Business units");
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
			super.unregister();
		}
	}

	public class Loading extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public BusinessUnitsTemplate.Loading. _39_31_01131215905 _39_31_01131215905;

		public Loading(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_39_31_01131215905 == null) _39_31_01131215905 = register(new _39_31_01131215905(box()).<_39_31_01131215905>id("a2134995911").owner(AbstractBusinessUnitsTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (_39_31_01131215905 != null) _39_31_01131215905.unregister();
		}

		public class _39_31_01131215905 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

			public _39_31_01131215905(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}

	public class UnitsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public BusinessUnitsTemplate.UnitsBlock. Units units;

		public UnitsBlock(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (units == null) units = AbstractBusinessUnitsTemplate.this.units = register(new Units((UnitBox)box()).<Units>id("a_767586365").owner(AbstractBusinessUnitsTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (units != null) units.unregister();
		}

		public class Units extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,BusinessUnitTemplate, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,BusinessUnitTemplate, java.lang.Void> {

			public Units(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}

			@Override
			public BusinessUnitTemplate add(java.lang.Void value) {
				BusinessUnitTemplate child = new BusinessUnitTemplate(box());
				child.id(java.util.UUID.randomUUID().toString());
				add(child, "units");
				notifyAdd(child);
				return child;
			}
			@Override
			public void remove(BusinessUnitTemplate child) {
				removeChild(child, "units");
			}
			public void clear() {
				super.clear("units");
			}
		}
	}
}
